import axios from 'axios'
import { Corpus, UUID } from '@/types'
import { unique } from '.'

export const listCorpora = unique(async (): Promise<Corpus[]> => (await axios.get('/corpus/')).data)

// The name is required, everything else is optional
type CorpusEditPayload = Pick<Corpus, 'name'> & Partial<Pick<Corpus, 'description' | 'public' | 'top_level_type' | 'indexable'>>

export const createCorpus = async (corpus: CorpusEditPayload): Promise<Corpus> => (await axios.post('/corpus/', corpus)).data

export const updateCorpus = async (id: UUID, payload: CorpusEditPayload) => (await axios.patch(`/corpus/${id}/`, payload)).data

export const destroyCorpus = unique((corpusId: UUID) => axios.delete(`/corpus/${corpusId}/`))
