import axios from 'axios'
import { assert } from 'chai'
import { createPinia, setActivePinia } from 'pinia'
import { useImageStore, useNotificationStore } from '@/stores'
import { elementsSample } from '../samples'
import { FakeAxios } from '../testhelpers'

describe('image', () => {
  let mock, imageStore, notificationStore

  before('Setting up mocks', () => {
    mock = new FakeAxios(axios)
    setActivePinia(createPinia())
  })

  beforeEach(() => {
    setActivePinia(createPinia())
    imageStore = useImageStore()
    notificationStore = useNotificationStore()
  })

  afterEach(() => {
    // Remove any handlers, but leave mocking in place
    mock.reset()
    imageStore.$reset()
  })

  after('Removing Axios mock', () => {
    // Remove mocking entirely
    mock.restore()
  })

  it('setElements', () => {
    imageStore.setElements('imageid', elementsSample)
    assert.deepStrictEqual(imageStore.$state, {
      elements: {
        ...elementsSample,
        imageId: 'imageid'
      }
    })
  })

  describe('listElements', () => {
    it('lists elements on an image', async () => {
      mock.onGet('/image/imageid/elements/').reply(200, elementsSample)

      await imageStore.listElements({ id: 'imageid' })

      assert.deepStrictEqual(imageStore.$state, {
        elements: {
          ...elementsSample,
          imageId: 'imageid'
        }
      })
    })

    it('handles errors', async () => {
      mock.onGet('/image/imageid/elements/').reply(500)

      await imageStore.listElements({ id: 'imageid' })

      assert.deepStrictEqual(imageStore.$state, {
        elements: null
      })

      assert.deepStrictEqual(notificationStore.notifications, [
        {
          id: 0,
          type: 'error',
          text: 'Request failed with status code 500'
        }
      ])
    })
  })
})
