import { assert } from 'chai'
import { createPinia, setActivePinia } from 'pinia'
import { useNotificationStore } from '@/stores'

describe('notification', () => {
  let store

  beforeEach(() => {
    setActivePinia(createPinia())
    store = useNotificationStore()
  })

  describe('notify', () => {
    it('creates a notification', () => {
      assert.deepStrictEqual(store.notifications, [])
      const notification = { id: 42, type: 'info', text: 'Something' }
      store.notify(notification)
      assert.deepStrictEqual(store.notifications, [notification])
    })

    it('automatically assigns an ID if not set', () => {
      assert.deepStrictEqual(store.notifications, [])
      const notification = { type: 'info', text: 'Something' }
      store.notify(notification)
      assert.deepStrictEqual(store.notifications, [
        {
          ...notification,
          id: 0
        }
      ])
    })

    it('fails on an incorrect notification type', () => {
      assert.throws(() => store.notify({ type: 'toast', text: 'mmm, bread' }), 'Unsupported message type toast')
    })
  })

  describe('remove', () => {
    it('removes a notification by ID', () => {
      const notification1 = { id: 42, type: 'info', text: 'Something' }
      const notification2 = { id: 1337, type: 'warning', text: 'Something else' }
      store.notifications = [
        notification1,
        notification2
      ]
      store.remove(1337)
      assert.deepStrictEqual(store.notifications, [notification1])
    })

    it('ignores non-existent IDs', () => {
      const notification = { id: 42, type: 'info', text: 'Something' }
      store.notifications = [notification]
      store.remove(999)
      assert.deepStrictEqual(store.notifications, [notification])
    })
  })
})
